<?php
// Enable error reporting
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Settings
$cardNumber = isset($_GET['card_number']) ? $_GET['card_number'] : 'test123';
$keyPassphrase = 'test'; // From your test script

// Paths
$certDir = __DIR__ . '/../certs/';
$signerCertPath = $certDir . 'signerCert.pem';
$signerKeyPath = $certDir . 'signerKey.pem';
$wwdrCertPath = $certDir . 'Apple Worldwide Developer Relations Certification Authority.pem';
$passesDir = __DIR__ . '/../passes/';
$tempDir = $passesDir . 'tmp/';
$passFile = $passesDir . $cardNumber . '.pkpass';

// Create temp directory for this pass
$passDir = $tempDir . uniqid('pass_');
if (!is_dir($tempDir)) mkdir($tempDir, 0777, true);
if (!is_dir($passDir)) mkdir($passDir, 0777, true);

echo "Working directory: " . $passDir . "<br>";

// Create pass.json
$pass = [
    'formatVersion' => 1,
    'passTypeIdentifier' => 'pass.pointify.pk',
    'teamIdentifier' => 'C7CH6P3GLR',
    'organizationName' => 'Pointify',
    'description' => 'Loyalty Card',
    'serialNumber' => $cardNumber,
    'foregroundColor' => 'rgb(0, 0, 0)',
    'backgroundColor' => 'rgb(255, 255, 255)',
    'storeCard' => [
        'primaryFields' => [[
            'key' => 'customer',
            'label' => 'CUSTOMER',
            'value' => 'Test Customer'
        ]],
        'secondaryFields' => [[
            'key' => 'stamps',
            'label' => 'STAMPS',
            'value' => '5'
        ]]
    ],
    'barcode' => [
        'message' => $cardNumber,
        'format' => 'PKBarcodeFormatPDF417',
        'messageEncoding' => 'iso-8859-1',
        'altText' => $cardNumber
    ]
];

file_put_contents($passDir . '/pass.json', json_encode($pass));
echo "Created pass.json<br>";

// Copy required images from the template dir
$passImagesDir = __DIR__ . '/../assets/pass_images/';
$requiredImages = ['icon.png', 'icon@2x.png', 'logo.png', 'logo@2x.png'];
foreach ($requiredImages as $img) {
    if (file_exists($passImagesDir . $img)) {
        copy($passImagesDir . $img, $passDir . '/' . $img);
        echo "Copied $img<br>";
    } else {
        die("Missing required image: $img");
    }
}

// Create manifest
$manifest = [];
$files = glob($passDir . '/*');
foreach ($files as $file) {
    if (is_file($file) && basename($file) != 'manifest.json' && basename($file) != 'signature') {
        $manifest[basename($file)] = sha1_file($file);
    }
}
file_put_contents($passDir . '/manifest.json', json_encode($manifest));
echo "Created manifest.json<br>";

// Sign the manifest
$manifestData = file_get_contents($passDir . '/manifest.json');
$tempManifestFile = $tempDir . 'manifest_' . uniqid() . '.json';
file_put_contents($tempManifestFile, $manifestData);

// Load key and certificate
$pkeyid = openssl_pkey_get_private(file_get_contents($signerKeyPath), $keyPassphrase);
$cert = file_get_contents($signerCertPath);
$wwdr = file_get_contents($wwdrCertPath);

if (!$pkeyid) {
    die("Error loading private key: " . openssl_error_string());
}

echo "Loaded certificates and keys<br>";

// Sign
if (!openssl_pkcs7_sign(
    $tempManifestFile, 
    $passDir . '/signature',
    $cert,
    [$pkeyid, $keyPassphrase],
    [],
    PKCS7_BINARY | PKCS7_DETACHED,
    $wwdrCertPath
)) {
    die("Error signing manifest: " . openssl_error_string());
}

// Extract signature
$signatureContent = file_get_contents($passDir . '/signature');
$signature = '';
if (preg_match('~Content-Disposition:[^\n]+\s*?([A-Za-z0-9+=/\r\n]+)\s*?--~', $signatureContent, $matches)) {
    $signature = base64_decode(preg_replace('~\s+~', '', $matches[1]));
} elseif (preg_match('~\n\n(.+)~s', $signatureContent, $matches)) {
    $signature = base64_decode(trim($matches[1]));
} else {
    die("Could not extract signature data");
}

file_put_contents($passDir . '/signature', $signature);
echo "Created signature<br>";

// Create .pkpass (zip)
$zip = new ZipArchive();
if ($zip->open($passFile, ZipArchive::CREATE | ZipArchive::OVERWRITE) !== TRUE) {
    die("Cannot create ZIP archive");
}

$filesToZip = ['pass.json', 'manifest.json', 'signature'];
foreach ($requiredImages as $img) {
    $filesToZip[] = $img;
}

foreach ($filesToZip as $file) {
    if (file_exists($passDir . '/' . $file)) {
        $zip->addFile($passDir . '/' . $file, $file);
        echo "Added $file to zip<br>";
    }
}

$zip->close();
echo "Created .pkpass file<br>";

// Clean up
unlink($tempManifestFile);
foreach (glob($passDir . '/*') as $file) {
    unlink($file);
}
rmdir($passDir);

// Download link
echo "<h2>Pass file created successfully</h2>";
echo "<p>Download your pass file:</p>";
echo "<a href='download_pass.php?file=" . basename($passFile) . "' style='background:#000; color:#fff; padding:10px 20px; text-decoration:none; border-radius:5px;'>Download Pass</a>";
?> 