<?php
// Enable error reporting 
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
?>
<!DOCTYPE html>
<html>
<head>
    <title>Pass Debug</title>
    <style>
        body { font-family: monospace; padding: 20px; }
        pre { background: #f5f5f5; padding: 10px; overflow: auto; }
        .success { color: green; }
        .error { color: red; }
        .step { margin-top: 20px; border-top: 1px solid #ccc; padding-top: 10px; }
    </style>
</head>
<body>
    <h1>Apple Wallet Pass Debug Tool</h1>
    
    <?php
    echo "<div class='step'>";
    echo "<h2>1. Certificate Information</h2>";
    
    // Paths
    $certDir = __DIR__ . '/../certs/';
    $signerCertPath = $certDir . 'signerCert.pem';
    $signerKeyPath = $certDir . 'signerKey.pem';
    $wwdrCertPath = $certDir . 'Apple Worldwide Developer Relations Certification Authority.pem';
    $keyPassphrase = 'test';
    
    // Check files
    echo "Signer Certificate: " . (file_exists($signerCertPath) ? "<span class='success'>Found</span>" : "<span class='error'>Missing</span>") . "<br>";
    echo "Signer Key: " . (file_exists($signerKeyPath) ? "<span class='success'>Found</span>" : "<span class='error'>Missing</span>") . "<br>";
    echo "WWDR Certificate: " . (file_exists($wwdrCertPath) ? "<span class='success'>Found</span>" : "<span class='error'>Missing</span>") . "<br>";
    
    // Check certificate details
    if (file_exists($signerCertPath)) {
        $certData = openssl_x509_parse(file_get_contents($signerCertPath));
        echo "<h3>Signer Certificate Details:</h3>";
        echo "<pre>";
        echo "Subject: " . $certData['subject']['CN'] . "\n";
        echo "Issuer: " . $certData['issuer']['CN'] . "\n";
        echo "Valid Until: " . date('Y-m-d H:i:s', $certData['validTo_time_t']) . "\n";
        echo "</pre>";
    }
    
    // Test private key
    if (file_exists($signerKeyPath)) {
        $privateKey = openssl_pkey_get_private(file_get_contents($signerKeyPath), $keyPassphrase);
        if ($privateKey) {
            echo "<span class='success'>Private key loaded successfully</span><br>";
            openssl_pkey_free($privateKey);
        } else {
            echo "<span class='error'>Failed to load private key: " . openssl_error_string() . "</span><br>";
        }
    }
    echo "</div>";
    
    echo "<div class='step'>";
    echo "<h2>2. Pass Template Structure</h2>";
    
    // Template location
    $passesDir = __DIR__ . '/../passes/';
    $templateDir = $passesDir . 'templates/loyalty/';
    echo "Template Directory: " . $templateDir . "<br>";
    
    if (is_dir($templateDir)) {
        echo "<pre>";
        $files = scandir($templateDir);
        foreach ($files as $file) {
            if ($file != '.' && $file != '..') {
                echo $file . " (" . filesize($templateDir . $file) . " bytes)\n";
            }
        }
        echo "</pre>";
        
        // Check pass.json structure
        if (file_exists($templateDir . 'pass.json')) {
            $passJson = json_decode(file_get_contents($templateDir . 'pass.json'), true);
            if ($passJson) {
                echo "<h3>pass.json Structure:</h3>";
                echo "<pre>";
                print_r($passJson);
                echo "</pre>";
            } else {
                echo "<span class='error'>Error parsing pass.json: " . json_last_error_msg() . "</span><br>";
            }
        }
    } else {
        echo "<span class='error'>Template directory not found</span><br>";
    }
    echo "</div>";
    
    echo "<div class='step'>";
    echo "<h2>3. Manual Pass Creation Test</h2>";
    
    // Create a test pass
    $tempDir = $passesDir . 'tmp/';
    $passDir = $tempDir . 'debug_pass_' . uniqid();
    if (!is_dir($tempDir)) mkdir($tempDir, 0777, true);
    if (!is_dir($passDir)) mkdir($passDir, 0777, true);
    
    echo "Working directory: " . $passDir . "<br>";
    
    // Generate a minimal pass.json
    $serialNumber = 'debug-' . uniqid();
    $pass = [
        'formatVersion' => 1,
        'passTypeIdentifier' => 'pass.pointify.pk',
        'teamIdentifier' => 'C7CH6P3GLR',
        'serialNumber' => $serialNumber,
        'organizationName' => 'Pointify',
        'description' => 'Debug Loyalty Card',
        'storeCard' => [
            'primaryFields' => [
                [
                    'key' => 'debug',
                    'label' => 'DEBUG',
                    'value' => 'Test Pass'
                ]
            ]
        ],
        'barcode' => [
            'message' => $serialNumber,
            'format' => 'PKBarcodeFormatQR',
            'messageEncoding' => 'iso-8859-1'
        ]
    ];
    
    file_put_contents($passDir . '/pass.json', json_encode($pass));
    echo "Created pass.json<br>";
    
    // Copy required images
    $passImagesDir = __DIR__ . '/../assets/pass_images/';
    $requiredImages = ['icon.png', 'icon@2x.png', 'logo.png', 'logo@2x.png'];
    foreach ($requiredImages as $img) {
        if (file_exists($passImagesDir . $img)) {
            copy($passImagesDir . $img, $passDir . '/' . $img);
            echo "Copied $img<br>";
        } else {
            echo "<span class='error'>Missing required image: $img</span><br>";
        }
    }
    
    // Create manifest
    $manifest = [];
    $files = glob($passDir . '/*');
    foreach ($files as $file) {
        if (is_file($file) && basename($file) != 'manifest.json' && basename($file) != 'signature') {
            $manifest[basename($file)] = sha1_file($file);
        }
    }
    file_put_contents($passDir . '/manifest.json', json_encode($manifest));
    echo "Created manifest.json:<br><pre>" . json_encode($manifest, JSON_PRETTY_PRINT) . "</pre>";
    
    // Sign the manifest
    $manifestData = file_get_contents($passDir . '/manifest.json');
    $tempManifestFile = $tempDir . 'manifest_' . uniqid() . '.json';
    file_put_contents($tempManifestFile, $manifestData);
    
    // Load key and certificate
    $pkeyid = openssl_pkey_get_private(file_get_contents($signerKeyPath), $keyPassphrase);
    $cert = file_get_contents($signerCertPath);
    
    if (!$pkeyid) {
        echo "<span class='error'>Error loading private key: " . openssl_error_string() . "</span><br>";
    } else {
        echo "Loaded certificates and keys<br>";
        
        // Sign
        if (!openssl_pkcs7_sign(
            $tempManifestFile, 
            $passDir . '/signature',
            $cert,
            [$pkeyid, $keyPassphrase],
            [],
            PKCS7_BINARY | PKCS7_DETACHED,
            $wwdrCertPath
        )) {
            echo "<span class='error'>Error signing manifest: " . openssl_error_string() . "</span><br>";
        } else {
            echo "Manifest signed successfully<br>";
            
            // Examine raw signature file
            $signatureRaw = file_get_contents($passDir . '/signature');
            echo "Raw signature (first 200 chars):<br><pre>" . htmlspecialchars(substr($signatureRaw, 0, 200)) . "...</pre>";
            
            // Extract signature
            $signature = '';
            if (preg_match('~Content-Disposition:[^\n]+\s*?([A-Za-z0-9+=/\r\n]+)\s*?--~', $signatureRaw, $matches)) {
                $signature = base64_decode(preg_replace('~\s+~', '', $matches[1]));
                echo "Signature extracted with pattern 1<br>";
            } elseif (preg_match('~\n\n(.+)~s', $signatureRaw, $matches)) {
                $signature = base64_decode(trim($matches[1]));
                echo "Signature extracted with pattern 2<br>";
            } else {
                echo "<span class='error'>Could not extract signature data</span><br>";
            }
            
            if ($signature) {
                file_put_contents($passDir . '/signature', $signature);
                echo "Processed signature size: " . strlen($signature) . " bytes<br>";
                
                // Create .pkpass 
                $passFile = $passesDir . 'debug_' . $serialNumber . '.pkpass';
                $zip = new ZipArchive();
                if ($zip->open($passFile, ZipArchive::CREATE | ZipArchive::OVERWRITE) !== TRUE) {
                    echo "<span class='error'>Cannot create ZIP archive</span><br>";
                } else {
                    $filesToZip = ['pass.json', 'manifest.json', 'signature'];
                    foreach ($requiredImages as $img) {
                        $filesToZip[] = $img;
                    }
                    
                    foreach ($filesToZip as $file) {
                        if (file_exists($passDir . '/' . $file)) {
                            $zip->addFile($passDir . '/' . $file, $file);
                            echo "Added $file to zip<br>";
                        }
                    }
                    
                    $zip->close();
                    echo "<span class='success'>Created .pkpass file: " . basename($passFile) . "</span><br>";
                    
                    // Create download link
                    echo "<p><a href='download_pass.php?file=" . basename($passFile) . "' style='background:#000; color:#fff; padding:10px 20px; text-decoration:none; border-radius:5px;'>Download Debug Pass</a></p>";
                }
            }
        }
    }
    
    // Show the temp directory structure
    echo "<h3>Pass Directory Structure:</h3>";
    echo "<pre>";
    $files = scandir($passDir);
    foreach ($files as $file) {
        if ($file != '.' && $file != '..') {
            echo $file . " (" . filesize($passDir . '/' . $file) . " bytes)\n";
        }
    }
    echo "</pre>";
    
    echo "</div>";
    ?>
    
    <div class="step">
        <h2>4. Try Different Approaches</h2>
        <p>Click below to try the other pass generation methods:</p>
        <p>
            <a href="basic_pass.php" style="background:#007bff; color:#fff; padding:10px 20px; text-decoration:none; border-radius:5px; margin-right: 10px;">Basic Pass</a>
            <a href="simple_pass.php?card_number=debug123" style="background:#28a745; color:#fff; padding:10px 20px; text-decoration:none; border-radius:5px; margin-right: 10px;">Simple Pass</a>
            <a href="generate_pass.php?card_number=LC202503224956" style="background:#dc3545; color:#fff; padding:10px 20px; text-decoration:none; border-radius:5px;">Full Pass</a>
        </p>
    </div>
</body>
</html> 