<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Check if file parameter is provided
if (!isset($_GET['file']) || empty($_GET['file'])) {
    die('File parameter is required');
}

// Sanitize filename to prevent directory traversal attacks
$filename = basename($_GET['file']);
$filepath = __DIR__ . '/../passes/' . $filename;

// Check if file exists
if (!file_exists($filepath)) {
    die('File not found: ' . htmlspecialchars($filename));
}

// Check if file is readable
if (!is_readable($filepath)) {
    die('File is not readable: ' . htmlspecialchars($filename));
}

// Get file size
$filesize = filesize($filepath);
if ($filesize === false) {
    die('Failed to get file size');
}

// Set appropriate headers for .pkpass file
header('Content-Type: application/vnd.apple.pkpass');
header('Content-Disposition: attachment; filename="' . $filename . '"');
header('Content-Length: ' . $filesize);
header('Pragma: no-cache');
header('Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0');
header('Expires: 0');
header('X-Apple-Wallet-Compatible: 1');

// Output file content
$handle = fopen($filepath, 'rb');
if ($handle === false) {
    die('Failed to open file for reading');
}

// Stream file in chunks to avoid memory issues with large files
while (!feof($handle)) {
    echo fread($handle, 8192);
    flush();
}
fclose($handle);
exit; 