<?php
// Final version of the wallet landing page - ultra minimalist approach
require_once '../includes/functions.php';

// Check for card number
if (!isset($_GET['card_number'])) {
    die("Card number is required");
}

$cardNumber = $_GET['card_number'];

// Get basic card details
try {
    $conn = getDbConnection();
    $stmt = $conn->prepare("
        SELECT lc.card_number, c.name, l.name as location_name
        FROM loyalty_cards lc
        JOIN customers c ON lc.customer_id = c.id
        JOIN locations l ON c.location_id = l.id
        WHERE lc.card_number = :card_number
    ");
    $stmt->bindParam(':card_number', $cardNumber);
    $stmt->execute();
    $card = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$card) {
        die("Invalid card number");
    }
} catch (Exception $e) {
    die("Database error");
}
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Final Apple Wallet Method</title>
    <style>
        body {
            font-family: -apple-system, BlinkMacSystemFont, sans-serif;
            margin: 0;
            padding: 20px;
            background-color: #f2f2f7;
            color: #000;
        }
        .container {
            max-width: 500px;
            margin: 0 auto;
            background: white;
            border-radius: 12px;
            overflow: hidden;
            box-shadow: 0 2px 8px rgba(0,0,0,0.1);
        }
        .header {
            background: #000;
            color: white;
            padding: 20px;
            text-align: center;
        }
        .header h1 {
            margin: 0;
            font-size: 20px;
            font-weight: 500;
        }
        .content {
            padding: 20px;
        }
        .card-info {
            margin-bottom: 25px;
            font-size: 15px;
        }
        .card-info p {
            margin: 8px 0;
        }
        .download-btn {
            display: block;
            background: #000;
            color: white;
            text-align: center;
            text-decoration: none;
            border-radius: 8px;
            padding: 12px;
            font-weight: 500;
            margin: 25px 0;
        }
        .download-btn:hover {
            background: #333;
        }
        .message {
            background: #f8f8f8;
            border-radius: 8px;
            padding: 15px;
            font-size: 14px;
            line-height: 1.5;
        }
        .back {
            text-align: center;
            margin-top: 20px;
        }
        .back a {
            color: #007aff;
            text-decoration: none;
            font-size: 14px;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>Add to Apple Wallet - Final Method</h1>
        </div>
        
        <div class="content">
            <div class="card-info">
                <p><strong>Card:</strong> <?php echo htmlspecialchars($card['card_number']); ?></p>
                <p><strong>Customer:</strong> <?php echo htmlspecialchars($card['name']); ?></p>
                <p><strong>Location:</strong> <?php echo htmlspecialchars($card['location_name']); ?></p>
            </div>
            
            <a href="final_simple_pass.php?card_number=<?php echo urlencode($cardNumber); ?>" class="download-btn">
                Download Pass for Apple Wallet
            </a>
            
            <div class="message">
                <p>This is our most simplified PKPass generation method. After downloading the pass file:</p>
                <ol style="padding-left: 20px; margin-bottom: 0;">
                    <li>Tap the downloaded file</li>
                    <li>Tap "Add" when prompted to add the pass to Apple Wallet</li>
                </ol>
            </div>
            
            <div class="back">
                <a href="wallet_quick.php?card_number=<?php echo urlencode($cardNumber); ?>">
                    ← Back to All Options
                </a>
            </div>
        </div>
    </div>
</body>
</html> 