<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Start output buffering
ob_start();

// Define environments
$environments = [
    'local' => [
        'name' => 'Local Development',
        'base_url' => 'http://localhost/erp/',
        'db' => [
            'host' => 'localhost',
            'username' => 'root',
            'password' => '',
            'database' => 'loyalty_card_system'
        ]
    ],
    'live' => [
        'name' => 'Live Server',
        'base_url' => 'https://dev.trimscloud.com/',
        'db' => [
            'host' => 'localhost',
            'username' => 'trimscloud_dev',
            'password' => 'Pakistan@1947',
            'database' => 'trimscloud_dev'
        ]
    ]
];

// Get current configuration
$currentConfig = [];
$currentEnvironment = '';

// Try to read the current configuration
if (file_exists(__DIR__ . '/setup/config.php')) {
    // Include the config file directly but suppress any notices about constants
    $oldErrorLevel = error_reporting();
    error_reporting(E_ERROR | E_PARSE);
    
    // Create a function to safely get the config
    function getConfigSafely($path) {
        include $path;
        return isset($config) ? $config : [];
    }
    
    $currentConfig = getConfigSafely(__DIR__ . '/setup/config.php');
    error_reporting($oldErrorLevel);
    
    // Detect current environment
    foreach ($environments as $key => $env) {
        if (isset($currentConfig['base_url']) && $currentConfig['base_url'] === $env['base_url']) {
            $currentEnvironment = $key;
            break;
        }
    }
}

// Generate config content for selected environment
$selectedEnv = $_GET['env'] ?? $currentEnvironment ?? 'local';
$configContent = '';

if (isset($environments[$selectedEnv])) {
    $config = $environments[$selectedEnv];
    
    $configContent = "<?php
// Base configuration for the Pointify
\$config = [
    // Base URL - change this based on your environment
    'base_url' => '{$config['base_url']}',
    
    // Database configuration
    'db' => [
        'host' => '{$config['db']['host']}',
        'username' => '{$config['db']['username']}',
        'password' => '{$config['db']['password']}',
        'database' => '{$config['db']['database']}'
    ],
    
    // Email configuration for OTP
    'email' => [
        'from' => 'test@trimscloud.com',
        'name' => 'Pointify',
        'smtp' => [
            'host' => 'mail.trimscloud.com',
            'port' => 465,
            'username' => 'test@trimscloud.com',
            'password' => 'Pakistan@1234x',
            'secure' => 'ssl' // Use 'tls' for port 587, 'ssl' for port 465
        ]
    ],
    
    // OTP configuration
    'otp' => [
        'length' => 6,
        'expiry' => 15 // minutes
    ]
];

// Define constants - only if not already defined
if (!defined('BASE_URL')) define('BASE_URL', \$config['base_url']);
if (!defined('ADMIN_URL')) define('ADMIN_URL', BASE_URL . 'admin/');
if (!defined('CUSTOMER_URL')) define('CUSTOMER_URL', BASE_URL . 'customer/');
if (!defined('ASSETS_URL')) define('ASSETS_URL', BASE_URL . 'assets/');
?>";
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manual Deployment - Pointify</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <style>
        pre {
            white-space: pre-wrap;
            word-wrap: break-word;
            background-color: #f7fafc;
            padding: 1rem;
            border-radius: 0.5rem;
            border: 1px solid #e2e8f0;
            overflow-x: auto;
        }
    </style>
</head>
<body class="bg-gray-100 min-h-screen p-4">
    <div class="container mx-auto max-w-4xl">
        <div class="bg-white rounded-lg shadow-md p-6 mb-6">
            <h1 class="text-2xl font-bold mb-6 text-center">Manual Deployment Helper</h1>
            
            <div class="mb-6">
                <h2 class="text-lg font-semibold mb-2">Current Environment</h2>
                <div class="bg-gray-50 p-4 rounded-lg">
                    <p><strong>Environment:</strong> <?php echo $currentEnvironment ? htmlspecialchars($environments[$currentEnvironment]['name']) : 'Not set'; ?></p>
                    <p><strong>Base URL:</strong> <?php echo htmlspecialchars($currentConfig['base_url'] ?? 'Not set'); ?></p>
                    <p><strong>Database:</strong> <?php echo htmlspecialchars($currentConfig['db']['database'] ?? 'Not set'); ?></p>
                </div>
            </div>
            
            <div class="mb-6">
                <h2 class="text-lg font-semibold mb-2">Select Environment</h2>
                <div class="flex space-x-2">
                    <?php foreach ($environments as $key => $env): ?>
                        <a href="?env=<?php echo $key; ?>" class="px-4 py-2 rounded-lg <?php echo $selectedEnv === $key ? 'bg-blue-500 text-white' : 'bg-gray-200 text-gray-700 hover:bg-gray-300'; ?>">
                            <?php echo htmlspecialchars($env['name']); ?>
                        </a>
                    <?php endforeach; ?>
                </div>
            </div>
            
            <?php if ($configContent): ?>
                <div class="mb-6">
                    <h2 class="text-lg font-semibold mb-2">Configuration for <?php echo htmlspecialchars($environments[$selectedEnv]['name']); ?></h2>
                    <p class="mb-2">Copy this content to <code>setup/config.php</code>:</p>
                    <pre><code><?php echo htmlspecialchars($configContent); ?></code></pre>
                    <button id="copyBtn" class="mt-2 bg-blue-500 text-white px-4 py-2 rounded hover:bg-blue-600">Copy to Clipboard</button>
                </div>
                
                <div class="mb-6">
                    <h2 class="text-lg font-semibold mb-2">Next Steps</h2>
                    <ol class="list-decimal pl-5 space-y-2">
                        <li>Copy the configuration above to <code>setup/config.php</code></li>
                        <li>Run the database setup by visiting <a href="<?php echo htmlspecialchars($environments[$selectedEnv]['base_url']); ?>setup/setup.php" class="text-blue-500 hover:underline" target="_blank">setup/setup.php</a></li>
                        <li>Clear your browser cookies to reset any existing sessions</li>
                        <li>Log in at <a href="<?php echo htmlspecialchars($environments[$selectedEnv]['base_url']); ?>admin/login.php" class="text-blue-500 hover:underline" target="_blank">admin/login.php</a></li>
                    </ol>
                </div>
            <?php endif; ?>
            
            <div class="mt-6 pt-6 border-t border-gray-200">
                <h2 class="text-lg font-semibold mb-2">Quick Links</h2>
                <div class="grid grid-cols-2 gap-2">
                    <a href="<?php echo htmlspecialchars($environments[$selectedEnv]['base_url']); ?>" class="bg-blue-500 text-white p-2 rounded text-center hover:bg-blue-600 transition">
                        Home
                    </a>
                    <a href="<?php echo htmlspecialchars($environments[$selectedEnv]['base_url'] . 'admin/login.php'); ?>" class="bg-green-500 text-white p-2 rounded text-center hover:bg-green-600 transition">
                        Admin Login
                    </a>
                    <a href="<?php echo htmlspecialchars($environments[$selectedEnv]['base_url'] . 'setup/setup.php'); ?>" class="bg-yellow-500 text-white p-2 rounded text-center hover:bg-yellow-600 transition">
                        Run Setup
                    </a>
                    <a href="<?php echo htmlspecialchars($environments[$selectedEnv]['base_url'] . 'check_paths.php'); ?>" class="bg-purple-500 text-white p-2 rounded text-center hover:bg-purple-600 transition">
                        Check Paths
                    </a>
                </div>
            </div>
        </div>
    </div>
    
    <script>
        document.getElementById('copyBtn').addEventListener('click', function() {
            const codeElement = document.querySelector('pre code');
            const textArea = document.createElement('textarea');
            textArea.value = codeElement.textContent;
            document.body.appendChild(textArea);
            textArea.select();
            document.execCommand('copy');
            document.body.removeChild(textArea);
            
            this.textContent = 'Copied!';
            setTimeout(() => {
                this.textContent = 'Copy to Clipboard';
            }, 2000);
        });
    </script>
</body>
</html>
<?php
// Flush output buffer
ob_end_flush();
?> 