# Apple Wallet Pass Implementation

This document guides you through the Apple Wallet (Passbook) integration for the Pointify loyalty card system.

## File Structure

```
/certs/
  - Apple Worldwide Developer Relations Certification Authority.pem
  - signerCert.pem  
  - signerKey.pem
  - Certificates.p12

/assets/pass_images/
  - icon.png (29x29px PNG)
  - icon@2x.png (58x58px PNG)
  - logo.png (160x50px PNG) 
  - logo@2x.png (320x100px PNG)
  - strip.png (320x84px PNG)
  - strip@2x.png (640x168px PNG)
  - thumbnail.png (optional)
  - thumbnail@2x.png (optional)

/passes/
  /tmp/ (temporary directory for pass generation)
```

## Required Images

The required pass images are located in the `/assets/pass_images/` directory:

- **icon.png**: 29x29 pixels
- **icon@2x.png**: 58x58 pixels
- **logo.png**: 160x50 pixels
- **logo@2x.png**: 320x100 pixels
- Optional: **strip.png**: 320x84 pixels (background image for the pass)
- Optional: **strip@2x.png**: 640x168 pixels (high resolution background image)
- Optional: **thumbnail.png**: 90x90 pixels (thumbnail image)
- Optional: **thumbnail@2x.png**: 180x180 pixels (high resolution thumbnail image)

## How It Works

1. The user views their digital loyalty card at `customer/card.php?card_number=CARDNUMBER`
2. They click the "Add to Apple Wallet" button
3. The system runs `generate_pass.php` which:
   - Fetches the user's current stamp count from the database
   - Creates a .pkpass file with the latest data
   - Signs the pass using the certificates
   - Serves it to the user with the correct MIME type

## Generating .pkpass Files

The `generate_pass.php` script handles this automatically:

1. Creates a temporary directory
2. Generates the pass.json with user data
3. Copies the required images from assets/pass_images
4. Creates a manifest.json with SHA1 hashes of all files
5. Signs the manifest using the certificates
6. Packages everything into a .pkpass file (zip archive)
7. Serves the file to the user

## Updating Pass Content

When a user adds or removes stamps via the admin interface, you should:

1. Update the stamp_count in the database (already implemented)
2. If you want to push updates to existing passes in users' Apple Wallets, you'll need to implement the Apple Push Notification Service for passes

## Testing

Use the `customer/test_certificates.php` script to verify your certificate setup is working correctly.

You can also use `customer/debug_pass.php` for detailed diagnostics of the pass generation process.

## Important Note

The certificate password from your test script is "test" (used in the generate_pass.php file).

## Apple Wallet Pass Type Identifier

Your Pass Type ID: `pass.pointify.pk`
Team ID: `C7CH6P3GLR` 