<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Start output buffering
ob_start();

// Define environments
$environments = [
    'local' => [
        'name' => 'Local Development',
        'base_url' => 'http://localhost/erp/',
        'db' => [
            'host' => 'localhost',
            'username' => 'root',
            'password' => '',
            'database' => 'loyalty_card_system'
        ]
    ],
    'live' => [
        'name' => 'Live Server',
        'base_url' => 'https://dev.trimscloud.com/',
        'db' => [
            'host' => 'localhost',
            'username' => 'trimscloud_dev',
            'password' => 'Pakistan@1947',
            'database' => 'trimscloud_dev'
        ]
    ]
];

// Process form submission
$message = '';
$messageType = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $environment = $_POST['environment'] ?? '';
    
    if (isset($environments[$environment])) {
        $config = $environments[$environment];
        
        // Update config.php
        if (updateConfigFile($config)) {
            $message = "Configuration updated to {$environments[$environment]['name']}";
            $messageType = "success";
            
            // Run setup if requested
            if (isset($_POST['run_setup']) && $_POST['run_setup'] === 'yes') {
                $setupResult = runSetup();
                if ($setupResult === true) {
                    $message .= " and database setup completed successfully";
                } else {
                    $message .= " but database setup failed: " . $setupResult;
                    $messageType = "error";
                }
            }
            
            // Clear sessions if requested
            if (isset($_POST['clear_sessions']) && $_POST['clear_sessions'] === 'yes') {
                clearSessions();
                $message .= " and sessions cleared";
            }
        } else {
            $message = "Failed to update configuration file";
            $messageType = "error";
        }
    } else {
        $message = "Invalid environment selected";
        $messageType = "error";
    }
}

// Function to update config.php
function updateConfigFile($config) {
    $configPath = __DIR__ . '/setup/config.php';
    
    $configContent = "<?php
// Base configuration for the Pointify
\$config = [
    // Base URL - change this based on your environment
    'base_url' => '{$config['base_url']}',
    
    // Database configuration
    'db' => [
        'host' => '{$config['db']['host']}',
        'username' => '{$config['db']['username']}',
        'password' => '{$config['db']['password']}',
        'database' => '{$config['db']['database']}'
    ],
    
    // Email configuration for OTP
    'email' => [
        'from' => 'test@trimscloud.com',
        'name' => 'Pointify',
        'smtp' => [
            'host' => 'mail.trimscloud.com',
            'port' => 465,
            'username' => 'test@trimscloud.com',
            'password' => 'Pakistan@1234x',
            'secure' => 'ssl' // Use 'tls' for port 587, 'ssl' for port 465
        ]
    ],
    
    // OTP configuration
    'otp' => [
        'length' => 6,
        'expiry' => 15 // minutes
    ]
];

// Define constants
define('BASE_URL', \$config['base_url']);
define('ADMIN_URL', BASE_URL . 'admin/');
define('CUSTOMER_URL', BASE_URL . 'customer/');
define('ASSETS_URL', BASE_URL . 'assets/');
?>";

    return file_put_contents($configPath, $configContent) !== false;
}

// Function to run setup.php
function runSetup() {
    try {
        // Include the setup file using absolute path
        $setupPath = __DIR__ . '/setup/setup.php';
        
        if (!file_exists($setupPath)) {
            return "Setup file not found at: " . $setupPath;
        }
        
        ob_start();
        include $setupPath;
        $output = ob_get_clean();
        
        if (strpos($output, 'Setup completed successfully') !== false) {
            return true;
        } else {
            return $output;
        }
    } catch (Exception $e) {
        return $e->getMessage();
    }
}

// Function to clear sessions
function clearSessions() {
    // Clear session data
    if (session_status() === PHP_SESSION_ACTIVE) {
        session_destroy();
    }
    
    // Delete session cookies
    if (isset($_COOKIE[session_name()])) {
        setcookie(session_name(), '', time() - 3600, '/');
    }
    
    return true;
}

// Get current configuration
$currentConfig = [];
$currentEnvironment = '';

if (file_exists(__DIR__ . '/setup/config.php')) {
    include __DIR__ . '/setup/config.php';
    $currentConfig = $config;
    
    // Detect current environment
    foreach ($environments as $key => $env) {
        if (isset($currentConfig['base_url']) && $currentConfig['base_url'] === $env['base_url']) {
            $currentEnvironment = $key;
            break;
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Simple Deployment - Pointify</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen flex items-center justify-center p-4">
    <div class="bg-white rounded-lg shadow-md p-6 w-full max-w-md">
        <h1 class="text-2xl font-bold mb-6 text-center">Pointify Deployment</h1>
        
        <?php if ($message): ?>
            <div class="<?php echo $messageType === 'error' ? 'bg-red-100 border-red-400 text-red-700' : 'bg-green-100 border-green-400 text-green-700'; ?> px-4 py-3 rounded mb-4 border">
                <?php echo htmlspecialchars($message); ?>
            </div>
        <?php endif; ?>
        
        <div class="mb-6">
            <h2 class="text-lg font-semibold mb-2">Current Environment</h2>
            <div class="bg-gray-50 p-4 rounded-lg">
                <p><strong>Environment:</strong> <?php echo $currentEnvironment ? htmlspecialchars($environments[$currentEnvironment]['name']) : 'Not set'; ?></p>
                <p><strong>Base URL:</strong> <?php echo htmlspecialchars($currentConfig['base_url'] ?? 'Not set'); ?></p>
                <p><strong>Database:</strong> <?php echo htmlspecialchars($currentConfig['db']['database'] ?? 'Not set'); ?></p>
            </div>
        </div>
        
        <form method="post" class="space-y-6">
            <div>
                <h2 class="text-lg font-semibold mb-2">Select Environment</h2>
                <div class="space-y-2">
                    <?php foreach ($environments as $key => $env): ?>
                        <label class="flex items-center p-3 border rounded-lg <?php echo $currentEnvironment === $key ? 'border-blue-500 bg-blue-50' : ''; ?>">
                            <input type="radio" name="environment" value="<?php echo $key; ?>" <?php echo $currentEnvironment === $key ? 'checked' : ''; ?> class="mr-2">
                            <div>
                                <div class="font-semibold"><?php echo htmlspecialchars($env['name']); ?></div>
                                <div class="text-sm text-gray-600"><?php echo htmlspecialchars($env['base_url']); ?></div>
                            </div>
                        </label>
                    <?php endforeach; ?>
                </div>
            </div>
            
            <div class="space-y-2">
                <label class="flex items-center">
                    <input type="checkbox" name="run_setup" value="yes" class="mr-2">
                    <span>Run database setup</span>
                </label>
                
                <label class="flex items-center">
                    <input type="checkbox" name="clear_sessions" value="yes" class="mr-2">
                    <span>Clear all sessions</span>
                </label>
            </div>
            
            <button type="submit" class="w-full bg-blue-500 text-white py-2 px-4 rounded-lg hover:bg-blue-600 transition duration-200">
                Deploy
            </button>
        </form>
        
        <div class="mt-6 pt-6 border-t border-gray-200">
            <h2 class="text-lg font-semibold mb-2">Quick Links</h2>
            <div class="grid grid-cols-2 gap-2">
                <a href="<?php echo htmlspecialchars($currentConfig['base_url'] ?? ''); ?>" class="bg-blue-500 text-white p-2 rounded text-center hover:bg-blue-600 transition">
                    Home
                </a>
                <a href="<?php echo htmlspecialchars(($currentConfig['base_url'] ?? '') . 'admin/login.php'); ?>" class="bg-green-500 text-white p-2 rounded text-center hover:bg-green-600 transition">
                    Admin Login
                </a>
            </div>
        </div>
    </div>
    
    <script>
        // Auto-check "Run setup" when deploying to a different environment
        document.addEventListener('DOMContentLoaded', function() {
            const environmentRadios = document.querySelectorAll('input[name="environment"]');
            const setupCheckbox = document.querySelector('input[name="run_setup"]');
            const currentEnvironment = '<?php echo $currentEnvironment; ?>';
            
            environmentRadios.forEach(radio => {
                radio.addEventListener('change', function() {
                    if (this.value !== currentEnvironment) {
                        setupCheckbox.checked = true;
                    }
                });
            });
        });
    </script>
</body>
</html>
<?php
// Flush output buffer
ob_end_flush();
?> 