# Apple Wallet API Implementation

This document describes the implementation of Apple's PassKit Web Service API for dynamic updates to passes in Apple Wallet.

## Table Structure

### `pass_registrations` Table

This table follows Apple's PassKit specifications for registering devices to receive push notifications.

| Field                    | Type         | Null | Key  | Default             | Extra          |
|--------------------------|--------------|------|------|---------------------|----------------|
| id                       | int(11)      | NO   | PRI  | NULL                | auto_increment |
| device_library_identifier| varchar(64)  | NO   | MUL  | NULL                |                |
| pass_type_identifier     | varchar(64)  | NO   |      | NULL                |                |
| pass_type_id             | varchar(64)  | NO   |      | NULL                |                |
| serial_number            | varchar(64)  | NO   |      | NULL                |                |
| push_token               | varchar(255) | NO   |      | NULL                |                |
| created_at               | timestamp    | NO   |      | CURRENT_TIMESTAMP   |                |
| updated_at               | timestamp    | NO   |      | CURRENT_TIMESTAMP   | on update CURRENT_TIMESTAMP |

### `pass_updates` Table

This table tracks the update status of passes for efficient change detection.

| Field         | Type      | Null | Key  | Default                  | Extra          |
|---------------|-----------|------|------|--------------------------|----------------|
| pass_id       | varchar(50)| NO  | PRI  | NULL                     |                |
| last_updated  | timestamp | NO   |      | CURRENT_TIMESTAMP        | on update CURRENT_TIMESTAMP |
| last_pushed   | timestamp | YES  |      | NULL                     |                |
| version       | int       | NO   |      | 1                        |                |

## API Endpoints

According to Apple's PassKit specifications, the following endpoints are implemented:

1. **Register a Device**
   - **URL**: `/v1/passes/{passTypeIdentifier}/{serialNumber}/register`
   - **Method**: `POST`
   - **Request Body**: 
     ```json
     {
       "pushToken": "Device push token from APNS",
       "deviceLibraryIdentifier": "Device identifier"
     }
     ```

2. **Unregister a Device**
   - **URL**: `/v1/passes/{passTypeIdentifier}/{serialNumber}/devices/{deviceLibraryIdentifier}`
   - **Method**: `DELETE`

3. **Get Latest Pass**
   - **URL**: `/v1/passes/{passTypeIdentifier}/{serialNumber}`
   - **Method**: `GET`
   - **Headers**:
     - `Authorization: ApplePass [authToken]`
     - `If-Modified-Since: [timestamp]` (optional)

## Push Notification System

The push notification system uses Apple's JWT-based APNs authentication with the APNs auth key provided:

- **Key ID**: `Y8H9GBCK64`
- **Team ID**: `C7CH6P3GLR`
- **Auth Key Path**: `certs/AuthKey_Y8H9GBCK64.p8`

When a loyalty card is updated (stamps added/removed), the system:

1. Updates the card in the database
2. Updates the last_updated timestamp in the pass_updates table
3. Sends push notifications to all registered devices for that pass
4. Increments the version number of the pass

## Implementation Files

- **index.php**: Handles the PassKit API endpoints
- **push.php**: Handles sending push notifications to registered devices
- **db_schema_update.php**: Updates the database schema to match Apple's requirements

## Apple Wallet Pass Configuration

For a pass to work with the update system, it must include:

1. A `webServiceURL` pointing to this API (https://dev.trimscloud.com/webservice/v1/passes/)
2. A unique `authenticationToken` for security
3. A `serialNumber` that uniquely identifies the pass (card_number in our system)

## Automatic Pass Updates

When a card is updated (stamps added or removed):

1. The pass_updates table is updated
2. A push notification is sent to all registered devices
3. The device requests the latest version of the pass
4. The updated pass is sent to the device
5. The Wallet app automatically updates the pass

This implementation ensures that passes in Apple Wallet are automatically updated without requiring manual user action. 