<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Set up logging
$logDir = __DIR__ . '/../../../logs';
if (!is_dir($logDir)) {
    mkdir($logDir, 0777, true);
}
$logFile = $logDir . '/db_schema_update.log';

// Log function for debugging
function logMessage($message) {
    global $logFile;
    file_put_contents($logFile, date('Y-m-d H:i:s') . ' - ' . $message . "\n", FILE_APPEND);
}

// Include database functions
require_once __DIR__ . '/../../../includes/functions.php';
$conn = getDbConnection();

logMessage("Starting database schema update");

try {
    // Check if the pass_registrations table exists
    $tableExists = false;
    try {
        $stmt = $conn->query("SELECT 1 FROM pass_registrations LIMIT 1");
        $tableExists = true;
    } catch (PDOException $e) {
        $tableExists = false;
    }

    if ($tableExists) {
        // Drop the existing table to recreate with new schema
        logMessage("Dropping existing pass_registrations table");
        $conn->exec("DROP TABLE pass_registrations");
    }

    // Create the table with the correct schema
    logMessage("Creating pass_registrations table with correct schema");
    $conn->exec("CREATE TABLE pass_registrations (
        id INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
        device_library_identifier VARCHAR(64) NOT NULL,
        pass_type_identifier VARCHAR(64) NOT NULL,
        pass_type_id VARCHAR(64) NOT NULL,
        serial_number VARCHAR(64) NOT NULL,
        push_token VARCHAR(255) NOT NULL,
        created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
        updated_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        PRIMARY KEY (id),
        UNIQUE KEY device_pass (device_library_identifier, pass_type_identifier, serial_number)
    )");

    // Also update the index.php file to handle the new schema
    logMessage("Database schema update completed successfully");
    echo "Database schema updated successfully.";

} catch (Exception $e) {
    logMessage("Error during schema update: " . $e->getMessage());
    echo "Error: " . $e->getMessage();
} 