<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Set up logging
$logDir = __DIR__ . '/../../../logs';
if (!is_dir($logDir)) {
    mkdir($logDir, 0777, true);
}
$logFile = $logDir . '/db_update.log';

// Log function for debugging
function logMessage($message) {
    global $logFile;
    file_put_contents($logFile, date('Y-m-d H:i:s') . ' - ' . $message . "\n", FILE_APPEND);
}

// Include database functions
require_once __DIR__ . '/../../../includes/functions.php';
$conn = getDbConnection();

logMessage("Starting database update");

try {
    // Check if the auth_token column exists in the loyalty_cards table
    $stmt = $conn->query("SHOW COLUMNS FROM loyalty_cards LIKE 'auth_token'");
    $columnExists = $stmt->rowCount() > 0;
    
    if (!$columnExists) {
        // Add the auth_token column
        $conn->exec("ALTER TABLE loyalty_cards ADD COLUMN auth_token VARCHAR(255) NULL");
        logMessage("Added auth_token column to loyalty_cards table");
    } else {
        logMessage("auth_token column already exists in loyalty_cards table");
    }
    
    // Set up pass registration tables
    $conn->exec("CREATE TABLE IF NOT EXISTS pass_registrations (
        id INT AUTO_INCREMENT PRIMARY KEY,
        pass_id VARCHAR(50) NOT NULL,
        device_id VARCHAR(100) NOT NULL,
        push_token VARCHAR(100) NOT NULL,
        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        UNIQUE KEY device_pass (device_id, pass_id)
    )");
    logMessage("Created pass_registrations table if it didn't exist");
    
    // Pass updates table
    $conn->exec("CREATE TABLE IF NOT EXISTS pass_updates (
        pass_id VARCHAR(50) PRIMARY KEY,
        last_updated TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        last_pushed TIMESTAMP NULL,
        version INT DEFAULT 1
    )");
    logMessage("Created pass_updates table if it didn't exist");
    
    // Check if there are any cards without auth tokens and generate them
    $stmt = $conn->query("SELECT card_number FROM loyalty_cards WHERE auth_token IS NULL OR auth_token = ''");
    $cardsWithoutTokens = $stmt->fetchAll(PDO::FETCH_COLUMN);
    
    if (!empty($cardsWithoutTokens)) {
        logMessage("Found " . count($cardsWithoutTokens) . " cards without auth tokens, generating tokens");
        
        foreach ($cardsWithoutTokens as $cardNumber) {
            // Generate a random auth token
            $authToken = bin2hex(random_bytes(16));
            
            // Update the card
            $stmt = $conn->prepare("UPDATE loyalty_cards SET auth_token = ? WHERE card_number = ?");
            $stmt->execute([$authToken, $cardNumber]);
            
            // Add to pass_updates table
            $stmt = $conn->prepare("INSERT IGNORE INTO pass_updates (pass_id) VALUES (?)");
            $stmt->execute([$cardNumber]);
            
            logMessage("Generated auth token for card $cardNumber: $authToken");
        }
    } else {
        logMessage("All cards already have auth tokens");
    }
    
    echo "Database update completed successfully. Check the log for details.";
    logMessage("Database update completed successfully");
} catch (Exception $e) {
    echo "Error: " . $e->getMessage();
    logMessage("Error: " . $e->getMessage());
} 